==> foundry_platform_sdk-0.22.0.tar.gz: foundry_platform_sdk-0.22.0/foundry/v2/ontologies/models/_sync_apply_action_response_v2.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

from pydantic import BaseModel

from foundry.v2.ontologies.models._action_results import ActionResults
from foundry.v2.ontologies.models._sync_apply_action_response_v2_dict import (
    SyncApplyActionResponseV2Dict,
)  # NOQA
from foundry.v2.ontologies.models._validate_action_response_v2 import (
    ValidateActionResponseV2,
)  # NOQA


class SyncApplyActionResponseV2(BaseModel):
    """SyncApplyActionResponseV2"""

    validation: Optional[ValidateActionResponseV2] = None

    edits: Optional[ActionResults] = None

    model_config = {"extra": "allow"}

    def to_dict(self) -> SyncApplyActionResponseV2Dict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            SyncApplyActionResponseV2Dict, self.model_dump(by_alias=True, exclude_unset=True)
        )

==> foundry_platform_sdk-0.66.0.tar.gz: foundry_platform_sdk-0.66.0/foundry/v2/ontologies/models/_sync_apply_action_response_v2.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

import pydantic

from foundry.v2.ontologies.models._action_results import ActionResults
from foundry.v2.ontologies.models._sync_apply_action_response_v2_dict import (
    SyncApplyActionResponseV2Dict,
)  # NOQA
from foundry.v2.ontologies.models._validate_action_response_v2 import (
    ValidateActionResponseV2,
)  # NOQA


class SyncApplyActionResponseV2(pydantic.BaseModel):
    """SyncApplyActionResponseV2"""

    validation: Optional[ValidateActionResponseV2] = None

    edits: Optional[ActionResults] = None

    model_config = {"extra": "allow"}

    def to_dict(self) -> SyncApplyActionResponseV2Dict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            SyncApplyActionResponseV2Dict, self.model_dump(by_alias=True, exclude_unset=True)
        )
